@@ -4,8 +4,8 @@ from pathlib import Path
 from lamin_logger import logger
 
 from ._settings import settings
-from ._settings_load import load_instance_settings
-from ._settings_store import instance_settings_file
+from .dev._settings_load import load_instance_settings
+from .dev._settings_store import instance_settings_file
 
 
 def delete(instance_name: str):
