@@ -1,7 +1,8 @@
 """Testing tools for Lamin's Python packages."""
-from lndb.test._env import get_package_name
 from lndb.test._migrations_e2e import migrate_clones
 from lndb.test._migrations_unit import (
     migration_id_is_consistent,
     model_definitions_match_ddl,
 )
+
+from ._env import get_package_name
